// Copyright (c) 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef THIRD_PARTY_BLINK_RENDERER_CORE_CSS_CSS_PROPERTY_NAMES_H_
#define THIRD_PARTY_BLINK_RENDERER_CORE_CSS_CSS_PROPERTY_NAMES_H_

#include <stddef.h>
#include "third_party/blink/public/mojom/use_counter/css_property_id.mojom-blink.h"
#include "third_party/blink/renderer/core/core_export.h"
#include "third_party/blink/renderer/platform/wtf/allocator/allocator.h"
#include "third_party/blink/renderer/platform/wtf/assertions.h"

namespace WTF {
class AtomicString;
class String;
}

namespace blink {

enum class CSSPropertyID {
    kInvalid = 0,
    kVariable = 1,
    kAnimationDelay = 2,
    kAnimationDirection = 3,
    kAnimationDuration = 4,
    kAnimationFillMode = 5,
    kAnimationIterationCount = 6,
    kAnimationName = 7,
    kAnimationPlayState = 8,
    kAnimationTimingFunction = 9,
    kTransitionDelay = 10,
    kTransitionDuration = 11,
    kTransitionProperty = 12,
    kTransitionTimingFunction = 13,
    kColor = 14,
    kColorScheme = 15,
    kDirection = 16,
    kFontFamily = 17,
    kFontFeatureSettings = 18,
    kFontKerning = 19,
    kFontOpticalSizing = 20,
    kFontSize = 21,
    kFontSizeAdjust = 22,
    kFontStretch = 23,
    kFontStyle = 24,
    kFontVariantCaps = 25,
    kFontVariantEastAsian = 26,
    kFontVariantLigatures = 27,
    kFontVariantNumeric = 28,
    kFontVariationSettings = 29,
    kFontWeight = 30,
    kForcedColorAdjust = 31,
    kInternalEffectiveZoom = 32,
    kInternalVisitedColor = 33,
    kTextOrientation = 34,
    kTextRendering = 35,
    kWebkitFontSmoothing = 36,
    kWebkitLocale = 37,
    kWebkitTextOrientation = 38,
    kWebkitWritingMode = 39,
    kWritingMode = 40,
    kZoom = 41,
    kAlignContent = 42,
    kAlignItems = 43,
    kAlignSelf = 44,
    kAlignmentBaseline = 45,
    kAll = 46,
    kBackdropFilter = 47,
    kBackfaceVisibility = 48,
    kBackgroundAttachment = 49,
    kBackgroundBlendMode = 50,
    kBackgroundClip = 51,
    kBackgroundColor = 52,
    kBackgroundImage = 53,
    kBackgroundOrigin = 54,
    kBackgroundPositionX = 55,
    kBackgroundPositionY = 56,
    kBackgroundRepeatX = 57,
    kBackgroundRepeatY = 58,
    kBackgroundSize = 59,
    kBaselineShift = 60,
    kBlockSize = 61,
    kBorderBlockEndColor = 62,
    kBorderBlockEndStyle = 63,
    kBorderBlockEndWidth = 64,
    kBorderBlockStartColor = 65,
    kBorderBlockStartStyle = 66,
    kBorderBlockStartWidth = 67,
    kBorderBottomColor = 68,
    kBorderBottomLeftRadius = 69,
    kBorderBottomRightRadius = 70,
    kBorderBottomStyle = 71,
    kBorderBottomWidth = 72,
    kBorderCollapse = 73,
    kBorderImageOutset = 74,
    kBorderImageRepeat = 75,
    kBorderImageSlice = 76,
    kBorderImageSource = 77,
    kBorderImageWidth = 78,
    kBorderInlineEndColor = 79,
    kBorderInlineEndStyle = 80,
    kBorderInlineEndWidth = 81,
    kBorderInlineStartColor = 82,
    kBorderInlineStartStyle = 83,
    kBorderInlineStartWidth = 84,
    kBorderLeftColor = 85,
    kBorderLeftStyle = 86,
    kBorderLeftWidth = 87,
    kBorderRightColor = 88,
    kBorderRightStyle = 89,
    kBorderRightWidth = 90,
    kBorderTopColor = 91,
    kBorderTopLeftRadius = 92,
    kBorderTopRightRadius = 93,
    kBorderTopStyle = 94,
    kBorderTopWidth = 95,
    kBottom = 96,
    kBoxShadow = 97,
    kBoxSizing = 98,
    kBreakAfter = 99,
    kBreakBefore = 100,
    kBreakInside = 101,
    kBufferedRendering = 102,
    kCaptionSide = 103,
    kCaretColor = 104,
    kClear = 105,
    kClip = 106,
    kClipPath = 107,
    kClipRule = 108,
    kColorInterpolation = 109,
    kColorInterpolationFilters = 110,
    kColorRendering = 111,
    kColumnCount = 112,
    kColumnFill = 113,
    kColumnGap = 114,
    kColumnRuleColor = 115,
    kColumnRuleStyle = 116,
    kColumnRuleWidth = 117,
    kColumnSpan = 118,
    kColumnWidth = 119,
    kContain = 120,
    kContent = 121,
    kContentSize = 122,
    kCounterIncrement = 123,
    kCounterReset = 124,
    kCursor = 125,
    kCx = 126,
    kCy = 127,
    kD = 128,
    kDisplay = 129,
    kDominantBaseline = 130,
    kEmptyCells = 131,
    kFill = 132,
    kFillOpacity = 133,
    kFillRule = 134,
    kFilter = 135,
    kFlexBasis = 136,
    kFlexDirection = 137,
    kFlexGrow = 138,
    kFlexShrink = 139,
    kFlexWrap = 140,
    kFloat = 141,
    kFloodColor = 142,
    kFloodOpacity = 143,
    kFontDisplay = 144,
    kGridAutoColumns = 145,
    kGridAutoFlow = 146,
    kGridAutoRows = 147,
    kGridColumnEnd = 148,
    kGridColumnStart = 149,
    kGridRowEnd = 150,
    kGridRowStart = 151,
    kGridTemplateAreas = 152,
    kGridTemplateColumns = 153,
    kGridTemplateRows = 154,
    kHeight = 155,
    kHyphens = 156,
    kImageOrientation = 157,
    kImageRendering = 158,
    kInherits = 159,
    kInitialValue = 160,
    kInlineSize = 161,
    kInsetBlockEnd = 162,
    kInsetBlockStart = 163,
    kInsetInlineEnd = 164,
    kInsetInlineStart = 165,
    kInternalVisitedBackgroundColor = 166,
    kInternalVisitedBorderBlockEndColor = 167,
    kInternalVisitedBorderBlockStartColor = 168,
    kInternalVisitedBorderBottomColor = 169,
    kInternalVisitedBorderInlineEndColor = 170,
    kInternalVisitedBorderInlineStartColor = 171,
    kInternalVisitedBorderLeftColor = 172,
    kInternalVisitedBorderRightColor = 173,
    kInternalVisitedBorderTopColor = 174,
    kInternalVisitedCaretColor = 175,
    kInternalVisitedColumnRuleColor = 176,
    kInternalVisitedFill = 177,
    kInternalVisitedOutlineColor = 178,
    kInternalVisitedStroke = 179,
    kInternalVisitedTextDecorationColor = 180,
    kInternalVisitedTextEmphasisColor = 181,
    kInternalVisitedTextFillColor = 182,
    kInternalVisitedTextStrokeColor = 183,
    kIsolation = 184,
    kJustifyContent = 185,
    kJustifyItems = 186,
    kJustifySelf = 187,
    kLeft = 188,
    kLetterSpacing = 189,
    kLightingColor = 190,
    kLineBreak = 191,
    kLineHeight = 192,
    kLineHeightStep = 193,
    kListStyleImage = 194,
    kListStylePosition = 195,
    kListStyleType = 196,
    kMarginBlockEnd = 197,
    kMarginBlockStart = 198,
    kMarginBottom = 199,
    kMarginInlineEnd = 200,
    kMarginInlineStart = 201,
    kMarginLeft = 202,
    kMarginRight = 203,
    kMarginTop = 204,
    kMarkerEnd = 205,
    kMarkerMid = 206,
    kMarkerStart = 207,
    kMask = 208,
    kMaskSourceType = 209,
    kMaskType = 210,
    kMaxBlockSize = 211,
    kMaxHeight = 212,
    kMaxInlineSize = 213,
    kMaxWidth = 214,
    kMaxZoom = 215,
    kMinBlockSize = 216,
    kMinHeight = 217,
    kMinInlineSize = 218,
    kMinWidth = 219,
    kMinZoom = 220,
    kMixBlendMode = 221,
    kObjectFit = 222,
    kObjectPosition = 223,
    kOffsetAnchor = 224,
    kOffsetDistance = 225,
    kOffsetPath = 226,
    kOffsetPosition = 227,
    kOffsetRotate = 228,
    kOpacity = 229,
    kOrder = 230,
    kOrientation = 231,
    kOrphans = 232,
    kOutlineColor = 233,
    kOutlineOffset = 234,
    kOutlineStyle = 235,
    kOutlineWidth = 236,
    kOverflowAnchor = 237,
    kOverflowBlock = 238,
    kOverflowInline = 239,
    kOverflowWrap = 240,
    kOverflowX = 241,
    kOverflowY = 242,
    kOverscrollBehaviorBlock = 243,
    kOverscrollBehaviorInline = 244,
    kOverscrollBehaviorX = 245,
    kOverscrollBehaviorY = 246,
    kPaddingBlockEnd = 247,
    kPaddingBlockStart = 248,
    kPaddingBottom = 249,
    kPaddingInlineEnd = 250,
    kPaddingInlineStart = 251,
    kPaddingLeft = 252,
    kPaddingRight = 253,
    kPaddingTop = 254,
    kPage = 255,
    kPaintOrder = 256,
    kPerspective = 257,
    kPerspectiveOrigin = 258,
    kPointerEvents = 259,
    kPosition = 260,
    kQuotes = 261,
    kR = 262,
    kResize = 263,
    kRight = 264,
    kRotate = 265,
    kRowGap = 266,
    kRx = 267,
    kRy = 268,
    kScale = 269,
    kScrollBehavior = 270,
    kScrollCustomization = 271,
    kScrollMarginBlockEnd = 272,
    kScrollMarginBlockStart = 273,
    kScrollMarginBottom = 274,
    kScrollMarginInlineEnd = 275,
    kScrollMarginInlineStart = 276,
    kScrollMarginLeft = 277,
    kScrollMarginRight = 278,
    kScrollMarginTop = 279,
    kScrollPaddingBlockEnd = 280,
    kScrollPaddingBlockStart = 281,
    kScrollPaddingBottom = 282,
    kScrollPaddingInlineEnd = 283,
    kScrollPaddingInlineStart = 284,
    kScrollPaddingLeft = 285,
    kScrollPaddingRight = 286,
    kScrollPaddingTop = 287,
    kScrollSnapAlign = 288,
    kScrollSnapStop = 289,
    kScrollSnapType = 290,
    kShapeImageThreshold = 291,
    kShapeMargin = 292,
    kShapeOutside = 293,
    kShapeRendering = 294,
    kSize = 295,
    kSpeak = 296,
    kSrc = 297,
    kStopColor = 298,
    kStopOpacity = 299,
    kStroke = 300,
    kStrokeDasharray = 301,
    kStrokeDashoffset = 302,
    kStrokeLinecap = 303,
    kStrokeLinejoin = 304,
    kStrokeMiterlimit = 305,
    kStrokeOpacity = 306,
    kStrokeWidth = 307,
    kSyntax = 308,
    kTabSize = 309,
    kTableLayout = 310,
    kTextAlign = 311,
    kTextAlignLast = 312,
    kTextAnchor = 313,
    kTextCombineUpright = 314,
    kTextDecorationColor = 315,
    kTextDecorationLine = 316,
    kTextDecorationSkipInk = 317,
    kTextDecorationStyle = 318,
    kTextIndent = 319,
    kTextJustify = 320,
    kTextOverflow = 321,
    kTextShadow = 322,
    kTextSizeAdjust = 323,
    kTextTransform = 324,
    kTextUnderlinePosition = 325,
    kTop = 326,
    kTouchAction = 327,
    kTransform = 328,
    kTransformBox = 329,
    kTransformOrigin = 330,
    kTransformStyle = 331,
    kTranslate = 332,
    kUnicodeBidi = 333,
    kUnicodeRange = 334,
    kUserSelect = 335,
    kUserZoom = 336,
    kVectorEffect = 337,
    kVerticalAlign = 338,
    kViewportFit = 339,
    kVisibility = 340,
    kWebkitAppRegion = 341,
    kWebkitAppearance = 342,
    kWebkitBorderHorizontalSpacing = 343,
    kWebkitBorderImage = 344,
    kWebkitBorderVerticalSpacing = 345,
    kWebkitBoxAlign = 346,
    kWebkitBoxDecorationBreak = 347,
    kWebkitBoxDirection = 348,
    kWebkitBoxFlex = 349,
    kWebkitBoxOrdinalGroup = 350,
    kWebkitBoxOrient = 351,
    kWebkitBoxPack = 352,
    kWebkitBoxReflect = 353,
    kWebkitFontSizeDelta = 354,
    kWebkitHighlight = 355,
    kWebkitHyphenateCharacter = 356,
    kWebkitLineBreak = 357,
    kWebkitLineClamp = 358,
    kWebkitMarginAfterCollapse = 359,
    kWebkitMarginBeforeCollapse = 360,
    kWebkitMarginBottomCollapse = 361,
    kWebkitMarginTopCollapse = 362,
    kWebkitMaskBoxImageOutset = 363,
    kWebkitMaskBoxImageRepeat = 364,
    kWebkitMaskBoxImageSlice = 365,
    kWebkitMaskBoxImageSource = 366,
    kWebkitMaskBoxImageWidth = 367,
    kWebkitMaskClip = 368,
    kWebkitMaskComposite = 369,
    kWebkitMaskImage = 370,
    kWebkitMaskOrigin = 371,
    kWebkitMaskPositionX = 372,
    kWebkitMaskPositionY = 373,
    kWebkitMaskRepeatX = 374,
    kWebkitMaskRepeatY = 375,
    kWebkitMaskSize = 376,
    kWebkitPerspectiveOriginX = 377,
    kWebkitPerspectiveOriginY = 378,
    kWebkitPrintColorAdjust = 379,
    kWebkitRtlOrdering = 380,
    kWebkitRubyPosition = 381,
    kWebkitTapHighlightColor = 382,
    kWebkitTextCombine = 383,
    kWebkitTextDecorationsInEffect = 384,
    kWebkitTextEmphasisColor = 385,
    kWebkitTextEmphasisPosition = 386,
    kWebkitTextEmphasisStyle = 387,
    kWebkitTextFillColor = 388,
    kWebkitTextSecurity = 389,
    kWebkitTextStrokeColor = 390,
    kWebkitTextStrokeWidth = 391,
    kWebkitTransformOriginX = 392,
    kWebkitTransformOriginY = 393,
    kWebkitTransformOriginZ = 394,
    kWebkitUserDrag = 395,
    kWebkitUserModify = 396,
    kWhiteSpace = 397,
    kWidows = 398,
    kWidth = 399,
    kWillChange = 400,
    kWordBreak = 401,
    kWordSpacing = 402,
    kX = 403,
    kY = 404,
    kZIndex = 405,
    kAnimation = 406,
    kBackground = 407,
    kBackgroundPosition = 408,
    kBackgroundRepeat = 409,
    kBorder = 410,
    kBorderBlock = 411,
    kBorderBlockColor = 412,
    kBorderBlockEnd = 413,
    kBorderBlockStart = 414,
    kBorderBlockStyle = 415,
    kBorderBlockWidth = 416,
    kBorderBottom = 417,
    kBorderColor = 418,
    kBorderImage = 419,
    kBorderInline = 420,
    kBorderInlineColor = 421,
    kBorderInlineEnd = 422,
    kBorderInlineStart = 423,
    kBorderInlineStyle = 424,
    kBorderInlineWidth = 425,
    kBorderLeft = 426,
    kBorderRadius = 427,
    kBorderRight = 428,
    kBorderSpacing = 429,
    kBorderStyle = 430,
    kBorderTop = 431,
    kBorderWidth = 432,
    kColumnRule = 433,
    kColumns = 434,
    kFlex = 435,
    kFlexFlow = 436,
    kFont = 437,
    kFontVariant = 438,
    kGap = 439,
    kGrid = 440,
    kGridArea = 441,
    kGridColumn = 442,
    kGridColumnGap = 443,
    kGridGap = 444,
    kGridRow = 445,
    kGridRowGap = 446,
    kGridTemplate = 447,
    kInset = 448,
    kInsetBlock = 449,
    kInsetInline = 450,
    kListStyle = 451,
    kMargin = 452,
    kMarginBlock = 453,
    kMarginInline = 454,
    kMarker = 455,
    kOffset = 456,
    kOutline = 457,
    kOverflow = 458,
    kOverscrollBehavior = 459,
    kPadding = 460,
    kPaddingBlock = 461,
    kPaddingInline = 462,
    kPageBreakAfter = 463,
    kPageBreakBefore = 464,
    kPageBreakInside = 465,
    kPlaceContent = 466,
    kPlaceItems = 467,
    kPlaceSelf = 468,
    kScrollMargin = 469,
    kScrollMarginBlock = 470,
    kScrollMarginInline = 471,
    kScrollPadding = 472,
    kScrollPaddingBlock = 473,
    kScrollPaddingInline = 474,
    kTextDecoration = 475,
    kTransition = 476,
    kWebkitColumnBreakAfter = 477,
    kWebkitColumnBreakBefore = 478,
    kWebkitColumnBreakInside = 479,
    kWebkitMarginCollapse = 480,
    kWebkitMask = 481,
    kWebkitMaskBoxImage = 482,
    kWebkitMaskPosition = 483,
    kWebkitMaskRepeat = 484,
    kWebkitTextEmphasis = 485,
    kWebkitTextStroke = 486,
    kAliasWebkitBorderEndColor = 591,
    kAliasWebkitBorderEndStyle = 592,
    kAliasWebkitBorderEndWidth = 593,
    kAliasWebkitBorderStartColor = 594,
    kAliasWebkitBorderStartStyle = 595,
    kAliasWebkitBorderStartWidth = 596,
    kAliasWebkitBorderBeforeColor = 577,
    kAliasWebkitBorderBeforeStyle = 578,
    kAliasWebkitBorderBeforeWidth = 579,
    kAliasWebkitBorderAfterColor = 574,
    kAliasWebkitBorderAfterStyle = 575,
    kAliasWebkitBorderAfterWidth = 576,
    kAliasWebkitMarginEnd = 712,
    kAliasWebkitMarginStart = 713,
    kAliasWebkitMarginBefore = 710,
    kAliasWebkitMarginAfter = 709,
    kAliasWebkitPaddingEnd = 762,
    kAliasWebkitPaddingStart = 763,
    kAliasWebkitPaddingBefore = 760,
    kAliasWebkitPaddingAfter = 759,
    kAliasWebkitLogicalWidth = 673,
    kAliasWebkitLogicalHeight = 573,
    kAliasWebkitMinLogicalWidth = 730,
    kAliasWebkitMinLogicalHeight = 728,
    kAliasWebkitMaxLogicalWidth = 725,
    kAliasWebkitMaxLogicalHeight = 723,
    kAliasWebkitBorderAfter = 925,
    kAliasWebkitBorderBefore = 926,
    kAliasWebkitBorderEnd = 934,
    kAliasWebkitBorderStart = 935,
    kAliasEpubCaptionSide = 615,
    kAliasEpubTextCombine = 895,
    kAliasEpubTextEmphasis = 997,
    kAliasEpubTextEmphasisColor = 897,
    kAliasEpubTextEmphasisStyle = 899,
    kAliasEpubTextOrientation = 550,
    kAliasEpubTextTransform = 836,
    kAliasEpubWordBreak = 913,
    kAliasEpubWritingMode = 551,
    kAliasWebkitAlignContent = 554,
    kAliasWebkitAlignItems = 555,
    kAliasWebkitAlignSelf = 556,
    kAliasWebkitAnimation = 918,
    kAliasWebkitAnimationDelay = 514,
    kAliasWebkitAnimationDirection = 515,
    kAliasWebkitAnimationDuration = 516,
    kAliasWebkitAnimationFillMode = 517,
    kAliasWebkitAnimationIterationCount = 518,
    kAliasWebkitAnimationName = 519,
    kAliasWebkitAnimationPlayState = 520,
    kAliasWebkitAnimationTimingFunction = 521,
    kAliasWebkitBackfaceVisibility = 560,
    kAliasWebkitBackgroundClip = 563,
    kAliasWebkitBackgroundOrigin = 566,
    kAliasWebkitBackgroundSize = 571,
    kAliasWebkitBorderBottomLeftRadius = 581,
    kAliasWebkitBorderBottomRightRadius = 582,
    kAliasWebkitBorderRadius = 939,
    kAliasWebkitBorderTopLeftRadius = 604,
    kAliasWebkitBorderTopRightRadius = 605,
    kAliasWebkitBoxShadow = 609,
    kAliasWebkitBoxSizing = 610,
    kAliasWebkitClipPath = 619,
    kAliasWebkitColumnCount = 624,
    kAliasWebkitColumnGap = 626,
    kAliasWebkitColumnRule = 945,
    kAliasWebkitColumnRuleColor = 627,
    kAliasWebkitColumnRuleStyle = 628,
    kAliasWebkitColumnRuleWidth = 629,
    kAliasWebkitColumnSpan = 630,
    kAliasWebkitColumnWidth = 631,
    kAliasWebkitColumns = 946,
    kAliasWebkitFilter = 647,
    kAliasWebkitFlex = 947,
    kAliasWebkitFlexBasis = 648,
    kAliasWebkitFlexDirection = 649,
    kAliasWebkitFlexFlow = 948,
    kAliasWebkitFlexGrow = 650,
    kAliasWebkitFlexShrink = 651,
    kAliasWebkitFlexWrap = 652,
    kAliasWebkitFontFeatureSettings = 530,
    kAliasWebkitJustifyContent = 697,
    kAliasWebkitOpacity = 741,
    kAliasWebkitOrder = 742,
    kAliasWebkitPerspective = 769,
    kAliasWebkitPerspectiveOrigin = 770,
    kAliasWebkitShapeImageThreshold = 803,
    kAliasWebkitShapeMargin = 804,
    kAliasWebkitShapeOutside = 805,
    kAliasWebkitTextSizeAdjust = 835,
    kAliasWebkitTransform = 840,
    kAliasWebkitTransformOrigin = 842,
    kAliasWebkitTransformStyle = 843,
    kAliasWebkitTransition = 988,
    kAliasWebkitTransitionDelay = 522,
    kAliasWebkitTransitionDuration = 523,
    kAliasWebkitTransitionProperty = 524,
    kAliasWebkitTransitionTimingFunction = 525,
    kAliasWebkitUserSelect = 847,
    kAliasWordWrap = 752,
};

const CSSPropertyID kCSSPropertyAliasList[] = {
    CSSPropertyID::kAliasWebkitBorderEndColor,
    CSSPropertyID::kAliasWebkitBorderEndStyle,
    CSSPropertyID::kAliasWebkitBorderEndWidth,
    CSSPropertyID::kAliasWebkitBorderStartColor,
    CSSPropertyID::kAliasWebkitBorderStartStyle,
    CSSPropertyID::kAliasWebkitBorderStartWidth,
    CSSPropertyID::kAliasWebkitBorderBeforeColor,
    CSSPropertyID::kAliasWebkitBorderBeforeStyle,
    CSSPropertyID::kAliasWebkitBorderBeforeWidth,
    CSSPropertyID::kAliasWebkitBorderAfterColor,
    CSSPropertyID::kAliasWebkitBorderAfterStyle,
    CSSPropertyID::kAliasWebkitBorderAfterWidth,
    CSSPropertyID::kAliasWebkitMarginEnd,
    CSSPropertyID::kAliasWebkitMarginStart,
    CSSPropertyID::kAliasWebkitMarginBefore,
    CSSPropertyID::kAliasWebkitMarginAfter,
    CSSPropertyID::kAliasWebkitPaddingEnd,
    CSSPropertyID::kAliasWebkitPaddingStart,
    CSSPropertyID::kAliasWebkitPaddingBefore,
    CSSPropertyID::kAliasWebkitPaddingAfter,
    CSSPropertyID::kAliasWebkitLogicalWidth,
    CSSPropertyID::kAliasWebkitLogicalHeight,
    CSSPropertyID::kAliasWebkitMinLogicalWidth,
    CSSPropertyID::kAliasWebkitMinLogicalHeight,
    CSSPropertyID::kAliasWebkitMaxLogicalWidth,
    CSSPropertyID::kAliasWebkitMaxLogicalHeight,
    CSSPropertyID::kAliasWebkitBorderAfter,
    CSSPropertyID::kAliasWebkitBorderBefore,
    CSSPropertyID::kAliasWebkitBorderEnd,
    CSSPropertyID::kAliasWebkitBorderStart,
    CSSPropertyID::kAliasEpubCaptionSide,
    CSSPropertyID::kAliasEpubTextCombine,
    CSSPropertyID::kAliasEpubTextEmphasis,
    CSSPropertyID::kAliasEpubTextEmphasisColor,
    CSSPropertyID::kAliasEpubTextEmphasisStyle,
    CSSPropertyID::kAliasEpubTextOrientation,
    CSSPropertyID::kAliasEpubTextTransform,
    CSSPropertyID::kAliasEpubWordBreak,
    CSSPropertyID::kAliasEpubWritingMode,
    CSSPropertyID::kAliasWebkitAlignContent,
    CSSPropertyID::kAliasWebkitAlignItems,
    CSSPropertyID::kAliasWebkitAlignSelf,
    CSSPropertyID::kAliasWebkitAnimation,
    CSSPropertyID::kAliasWebkitAnimationDelay,
    CSSPropertyID::kAliasWebkitAnimationDirection,
    CSSPropertyID::kAliasWebkitAnimationDuration,
    CSSPropertyID::kAliasWebkitAnimationFillMode,
    CSSPropertyID::kAliasWebkitAnimationIterationCount,
    CSSPropertyID::kAliasWebkitAnimationName,
    CSSPropertyID::kAliasWebkitAnimationPlayState,
    CSSPropertyID::kAliasWebkitAnimationTimingFunction,
    CSSPropertyID::kAliasWebkitBackfaceVisibility,
    CSSPropertyID::kAliasWebkitBackgroundClip,
    CSSPropertyID::kAliasWebkitBackgroundOrigin,
    CSSPropertyID::kAliasWebkitBackgroundSize,
    CSSPropertyID::kAliasWebkitBorderBottomLeftRadius,
    CSSPropertyID::kAliasWebkitBorderBottomRightRadius,
    CSSPropertyID::kAliasWebkitBorderRadius,
    CSSPropertyID::kAliasWebkitBorderTopLeftRadius,
    CSSPropertyID::kAliasWebkitBorderTopRightRadius,
    CSSPropertyID::kAliasWebkitBoxShadow,
    CSSPropertyID::kAliasWebkitBoxSizing,
    CSSPropertyID::kAliasWebkitClipPath,
    CSSPropertyID::kAliasWebkitColumnCount,
    CSSPropertyID::kAliasWebkitColumnGap,
    CSSPropertyID::kAliasWebkitColumnRule,
    CSSPropertyID::kAliasWebkitColumnRuleColor,
    CSSPropertyID::kAliasWebkitColumnRuleStyle,
    CSSPropertyID::kAliasWebkitColumnRuleWidth,
    CSSPropertyID::kAliasWebkitColumnSpan,
    CSSPropertyID::kAliasWebkitColumnWidth,
    CSSPropertyID::kAliasWebkitColumns,
    CSSPropertyID::kAliasWebkitFilter,
    CSSPropertyID::kAliasWebkitFlex,
    CSSPropertyID::kAliasWebkitFlexBasis,
    CSSPropertyID::kAliasWebkitFlexDirection,
    CSSPropertyID::kAliasWebkitFlexFlow,
    CSSPropertyID::kAliasWebkitFlexGrow,
    CSSPropertyID::kAliasWebkitFlexShrink,
    CSSPropertyID::kAliasWebkitFlexWrap,
    CSSPropertyID::kAliasWebkitFontFeatureSettings,
    CSSPropertyID::kAliasWebkitJustifyContent,
    CSSPropertyID::kAliasWebkitOpacity,
    CSSPropertyID::kAliasWebkitOrder,
    CSSPropertyID::kAliasWebkitPerspective,
    CSSPropertyID::kAliasWebkitPerspectiveOrigin,
    CSSPropertyID::kAliasWebkitShapeImageThreshold,
    CSSPropertyID::kAliasWebkitShapeMargin,
    CSSPropertyID::kAliasWebkitShapeOutside,
    CSSPropertyID::kAliasWebkitTextSizeAdjust,
    CSSPropertyID::kAliasWebkitTransform,
    CSSPropertyID::kAliasWebkitTransformOrigin,
    CSSPropertyID::kAliasWebkitTransformStyle,
    CSSPropertyID::kAliasWebkitTransition,
    CSSPropertyID::kAliasWebkitTransitionDelay,
    CSSPropertyID::kAliasWebkitTransitionDuration,
    CSSPropertyID::kAliasWebkitTransitionProperty,
    CSSPropertyID::kAliasWebkitTransitionTimingFunction,
    CSSPropertyID::kAliasWebkitUserSelect,
    CSSPropertyID::kAliasWordWrap,
};

const int kIntFirstCSSProperty = 2;
const CSSPropertyID firstCSSProperty = static_cast<CSSPropertyID>(kIntFirstCSSProperty);
const int numCSSProperties = 585;
const int kIntLastCSSProperty = 486;
const CSSPropertyID lastCSSProperty = static_cast<CSSPropertyID>(kIntLastCSSProperty);
const CSSPropertyID lastUnresolvedCSSProperty = static_cast<CSSPropertyID>(997);
const int numCSSPropertyIDs = static_cast<int>(lastUnresolvedCSSProperty) + 1;
const size_t maxCSSPropertyNameLength = 48;

inline int GetCSSPropertyIDIndex(CSSPropertyID id) {
    DCHECK_GE(id, firstCSSProperty);
    DCHECK_LE(id, lastCSSProperty);
    return static_cast<int>(id) - kIntFirstCSSProperty;
}

inline bool isCSSPropertyIDWithName(CSSPropertyID id)
{
    return id >= firstCSSProperty && id <= lastUnresolvedCSSProperty;
}

inline bool isValidCSSPropertyID(CSSPropertyID id)
{
    return id != CSSPropertyID::kInvalid;
}

inline CSSPropertyID convertToCSSPropertyID(int value)
{
    DCHECK_GE(value, static_cast<int>(CSSPropertyID::kInvalid));
    DCHECK_LE(value, kIntLastCSSProperty);
    return static_cast<CSSPropertyID>(value);
}

inline CSSPropertyID resolveCSSPropertyID(CSSPropertyID id)
{
    return convertToCSSPropertyID(static_cast<int>(id) & ~512);
}

inline bool isPropertyAlias(CSSPropertyID id) { return static_cast<int>(id) & 512; }

CSSPropertyID CORE_EXPORT unresolvedCSSPropertyID(const WTF::String&);

CSSPropertyID CORE_EXPORT cssPropertyID(const WTF::String&);

class CSSPropertyIDList {
  STACK_ALLOCATED();
 public:
    class Iterator {
      STACK_ALLOCATED();
     public:
      Iterator(int id) : id_(id) {}
      CSSPropertyID operator*() const { return convertToCSSPropertyID(id_); }
      Iterator& operator++() { id_++; return *this; }
      bool operator!=(const Iterator& i) const { return id_ != i.id_; }
     private:
      int id_;
    };
  Iterator begin() const { return Iterator(kIntFirstCSSProperty); }
  Iterator end() const { return Iterator(kIntLastCSSProperty + 1); }
};

mojom::blink::CSSSampleId CORE_EXPORT GetCSSSampleId(CSSPropertyID id);

}  // namespace blink

#endif  // THIRD_PARTY_BLINK_RENDERER_CORE_CSS_CSS_PROPERTY_NAMES_H_
